/**
 * MenuDashBoard Component
 *
 * This component is responsible for rendering the menu dashboard.
 * It fetches dashboard data based on user roles and displays them using `MenuDashboardCard` components.
 */

import  { useState, useEffect, useContext } from 'react';

import { Skeleton, Row } from 'antd';

import { GlobalContext } from './../../lib/';

import { Dashboard } from './../../models/';


import MenuDashboardCard from '../../modules/dashboard/components/dashboard-card/menu-dashboard-card';

/**
 * MenuDashBoard Component
 *
 * Renders the dashboard menu based on the provided `dashBoardIds`.
 * Fetches dashboard data and updates the UI accordingly.
 *
 * @param {Object} props - The component props
 * @param {Array} props.dashBoardIds - List of dashboard IDs to fetch data for
 * @param {Function} props.callback - Callback function for handling dashboard interactions
 * @returns {JSX.Element} The rendered MenuDashBoard component
 */
export default function MenuDashBoard({dashBoardIds, callback }) {
  const { user = {} } = useContext(GlobalContext);

  const [loading, setLoading] = useState(false);

  const [list, setList] = useState([]);

  /**
   * useEffect Hook
   *
   * Triggers the `getDashboard` function whenever the `user` object changes.
   * Ensures dashboard data is fetched whenever a user logs in or changes.
   */
  useEffect(() => {
    if (dashBoardIds) {
      
      getDashboard(); //Patiant list get function

    }

  }, [user]);

  /**
   * getDashboard Function
   *
   * Fetches the dashboard menu items based on `dashBoardIds`.
   * Updates the `list` state with the fetched data.
   */
  async function getDashboard() {
    setLoading(true);
    // Check if there are dashboard IDs to fetch data for
    if (dashBoardIds.length > 0) {
      Dashboard.loadMenuDashboards(dashBoardIds).then((response) => {
        let apiResponse = {};

        // @todo When the reporting tool is build , we have to consider all of these
        if (response.result && response.result.length) {
          apiResponse = response.result;
        } else if (response && response.length) {
          apiResponse = response;
        }

        setList(apiResponse);

        setLoading(false);
      });
    }
  }
  return (
    <span className="homepage">
      <div className="menu-dashboard ">
        <div className="dashboard-cards" style={{marginBottom:"10px"}}>
        
            <>
              {loading ? (
                <Skeleton active />
              ) : (
                <>
                  <Row gutter={20}>
                    {list
                      // Sort in ascending asc of id
                      .sort((a, b) => a.slno - b.slno)
                      .map((entry, key) => (
                        <MenuDashboardCard key={key} record={entry} callback={callback} />
                      ))}
                  </Row>
                </>
              )}
            </>
       
        </div>
      </div>
    </span>
  );
}
